@@ -10,6 +10,7 @@ that are only read during startup shouldn't be editable, since changing
 them would require an application reload.
 """
 
+from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 
 from mezzanine.conf import register_setting
@@ -22,13 +23,25 @@ register_setting(
     default=False,
 )
 
+_BLOG_URLS_DATE_FORMAT = ""
+if getattr(settings, "BLOG_URLS_USE_DATE", False):
+    _BLOG_URLS_DATE_FORMAT = "day"
+    from warnings import warn
+    warn("BLOG_URLS_USE_DATE setting is deprecated, please use the "
+        "BLOG_URLS_DATE_FORMAT setting with a value of 'year', 'month', "
+        "or 'day'.")
+
 register_setting(
-    name="BLOG_URLS_USE_DATE",
-    label=_("Use date URLs"),
-    description=_("If ``True``, URLs for blog post include the month and "
-        "year. Eg: /blog/yyyy/mm/slug/"),
+    name="BLOG_URLS_DATE_FORMAT",
+    label=_("Blog post URL date format"),
+    description=_("A string containing the value ``year``, ``month``, or "
+        "``day``, which controls the granularity of the date portion in the "
+        "URL for each blog post. Eg: ``year`` will define URLs in the format "
+        "/blog/yyyy/slug/, while ``day`` will define URLs with the format "
+        "/blog/yyyy/mm/dd/slug/. An empty string means the URLs will only "
+        "use the slug, and not contain any portion of the date at all."),
     editable=False,
-    default=False,
+    default=_BLOG_URLS_DATE_FORMAT,
 )
 
 register_setting(
