@@ -276,11 +276,11 @@ register_setting(
 )
 
 register_setting(
-    name="RICHTEXT_FILTER",
-    description=_("Dotted path to the function to call on a ``RichTextField`` "
-        "value before it is rendered to the template."),
+    name="RICHTEXT_FILTERS",
+    description=_("List of dotted paths to functions, called in order, on a "
+        "``RichTextField`` value before it is rendered to the template."),
     editable=False,
-    default=None,
+    default=(),
 )
 
 RICHTEXT_FILTER_LEVEL_HIGH = 1
