@@ -69,7 +69,10 @@ if (typeof tinyMCE != 'undefined') {
         paste_auto_cleanup_on_paste : true,
         paste_remove_styles: true,
         paste_remove_styles_if_webkit: true,
-        paste_strip_class_attributes: true
+        paste_strip_class_attributes: true,
+
+        // don't strip anything since this is handled by bleach
+        valid_elements : "*[*]"
 
 	});
 
