@@ -5,9 +5,13 @@ from django.core.urlresolvers import reverse
 from django.db.models import get_model, ObjectDoesNotExist
 from django.http import HttpResponse
 from django.shortcuts import redirect
-from django.utils.simplejson import dumps
 from django.utils.translation import ugettext_lazy as _
 
+try:
+    from json import dumps
+except ImportError:  # Python < 2.6
+    from django.utils.simplejson import dumps
+
 from mezzanine.conf import settings
 from mezzanine.generic.forms import ThreadedCommentForm, RatingForm
 from mezzanine.generic.models import Keyword
