@@ -10,8 +10,8 @@ class MenusField(MultiChoiceField):
     """
 
     def __init__(self, *args, **kwargs):
-        choices = [t[:2] for t in settings.PAGE_MENU_TEMPLATES]
-        default = settings.PAGE_MENU_TEMPLATES_DEFAULT
+        choices = [t[:2] for t in getattr(settings, "PAGE_MENU_TEMPLATES", [])]
+        default = getattr(settings, "PAGE_MENU_TEMPLATES_DEFAULT", None)
         if default is None:
             default = [t[0] for t in choices]
         elif not default:
